Reading and plotting data from the ISMN
=======================================

This example program chooses a random Network and Station and plots the first
variable,depth,sensor combination.

.. include::
   read_and_plot_ismn_data/Read and plot ISMN data.rst
